@@ -3,7 +3,7 @@
 #' \code{vif} calculates variance-inflation and generalized variance-inflation factors for linear, generalized linear.
 #'
 #' @param model A model object.
-#' @param merge_coef Logical, whether to merge with coefficients of model summary matrix. Default is FALSE.
+#' @param merge_coef Logical, whether to merge with coefficients of model summary matrix. Defaults to FALSE.
 #'
 #' @return A data frame with columns for variable and gvif, or additional columns for df and gvif^(1/(2*df)) if provided model uses factor variable.
 #'
@@ -64,7 +64,7 @@ vif = function(model, merge_coef = FALSE) {
       coefDF = as.data.frame(coef(summary(model)))
       coefDT = data.table(variable = row.names(coefDF),Estimate=coefDF[,1],
                  data.table(coefDF[,2:4])[,lapply(.SD,function(x) round(x,4))])
-      result = merge(coefDT, result, by='variable', all.x = TRUE)
+      result = merge(coefDT, result, by='variable', all.x = TRUE, sort = FALSE)
     } else {
       warning('The summary matrix cant merge with vif.')
     }
